'
' Simple interface to a Microchip MCP23S17 16-bit SPI I/O expander
' For the Proton BASIC compiler version 3.5.3.0 onwards using an Amicus18 board
'
    Include "Amicus18.inc"              ' Configure the compiler to use the 18F25K20 at 64MHz for the Amicus18 board
    Include "Amicus18_SPI.inc"          ' Load the Amicus18 SPI macros into the program

    Symbol MCP_CS = PORTC.2             ' MCP23S17 CS line connects here

    High MCP_CS                         ' Disable the SPI interface for now
'
' Open the SPI peripheral:
'                       Fosc/16 (4MHz operation)
'                       SPI mode 0:0
'                       Sample At End of the clock cycle
    SPI_Open(SPI_FOSC_16, MODE_00, SMPEND)
'
' Initialise the MCP23S17
'
' At initialisation, Chip_Address must be forced to "000"
' regardless of actual Mcpchip_Address value.
' After initialisation, once IOCON.HAEN is enabled,
' Mcpchip_Address is taken into account by the chip.
'
    Clear MCP_CS            ' Enable the SPI interface
    DelayCS 1               ' A one cycle delay before starting
    SPI_Write(%11110001)    ' Force ChipAdd to 000
    SPI_Write($0A)          ' Writing to IOCONA writes also to IOCONB
    SPI_Write(%00011000)    ' Init value for IOCON
    Set MCP_CS              ' Disable the SPI interface
'
' Write to the Tris of PortB and set it to all outputs
'
    Clear MCP_CS            ' Enable the SPI interface
    DelayCS 1               ' A one cycle delay before starting
    SPI_Write(%01000000)    ' Target address 000 and set the R/W Line To Write (0)
    SPI_Write($01)          ' We want to acces the IODIRB register.
    SPI_Write(%00000000)    ' Set to all outputs
    Set MCP_CS              ' Disable the SPI interface
'
' Write to the Latch of PortB
'
    Clear MCP_CS            ' Enable the SPI interface
    DelayCS 1               ' A one cycle delay before starting
    SPI_Write(%01000000)    ' Target address 000 and set the R/W Line To Write (0)
    SPI_Write($15)          ' We want to acces the OLATB register.
    SPI_Write(%11111111)    ' Set all outputs high
    Set MCP_CS              ' Disable the SPI interface




